# utils

## 1. Overview
A dual repository (JavaScript and Python) containing basic utils for development.  Minimum external dependencies should be used in order to keep the repository lightweight.

## 2. Content

### 2.1. JavaScript/TypeScript
See the [JavaScript](./src/js) directory for the available modules.

### 2.2. Python
See the [Python](./src/py) directory for the available modules.

## 3. Scripts

### 3.1. JavaScript/TypeScript
TBA

### 3.2. Python

#### 3.2.1. [wheel_server.py](./src/py/mat3ra/utils/scripts/wheel_server.py)

A script to build and serve the wheel file for development-time installation in a Python environment. Convenient to use with Pyodide.
